@@ -7,7 +7,6 @@ This is an implementation of django backend inteface for use
 django_jinja easy with django 1.8.
 """
 
-import copy
 import sys
 import os
 import os.path as path
@@ -20,14 +19,11 @@ from django.core import signals
 from django.core.exceptions import ImproperlyConfigured
 from django.dispatch import receiver
 from django.middleware import csrf
-from django.template import RequestContext
 from django.template import TemplateDoesNotExist
 from django.template import TemplateSyntaxError
 from django.template.backends.base import BaseEngine
-from django.template.backends.utils import csrf_input_lazy
-from django.template.backends.utils import csrf_token_lazy
 from django.template.context import BaseContext
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 from django.utils.functional import SimpleLazyObject
 from django.utils.functional import cached_property
 from django.utils.module_loading import import_string
@@ -77,7 +73,7 @@ class Template(object):
                 if token is None:
                     return 'NOTPROVIDED'
                 else:
-                    return smart_text(token)
+                    return smart_str(token)
 
             context["request"] = request
             context["csrf_token"] = SimpleLazyObject(_get_val)
@@ -285,11 +281,17 @@ class Jinja2(BaseEngine):
         try:
             return Template(self.env.get_template(template_name), self)
         except jinja2.TemplateNotFound as exc:
+            # Unlike django's template engine, jinja2 doesn't like windows-style path separators.
+            # But because django does, its docs encourage the usage of os.path.join().
+            # Rather than insisting that our users switch to posixpath.join(), this try block
+            # will attempt to retrieve the template path again with forward slashes on windows:
+            if os.name == 'nt' and '\\' in template_name:
+                try:
+                    return self.get_template(template_name.replace("\\", "/"))
+                except jinja2.TemplateNotFound:
+                    pass
 
-            if utils.DJANGO_18:
-                exc = TemplateDoesNotExist(exc.name)
-            else:
-                exc = TemplateDoesNotExist(exc.name, backend=self)
+            exc = TemplateDoesNotExist(exc.name, backend=self)
 
             utils.reraise(
                 TemplateDoesNotExist,
