@@ -1,10 +1,7 @@
 import re
-import os
 import os.path as path
 from importlib import import_module
 
-import django
-from django.conf import settings
 from django.template.context import BaseContext
 
 
@@ -47,7 +44,7 @@ def patch_django_for_autoescape():
     jinja autoescape implementation.
     """
     from django.utils import safestring
-    from django.forms.forms import BoundField
+    from django.forms.boundfield import BoundField
     from django.forms.utils import ErrorList
     from django.forms.utils import ErrorDict
 
