@@ -26,14 +26,10 @@ http://stackoverflow.com/questions/2090717/getting-translation-strings-for-jinja
 
 import re
 
-from django import VERSION as DJANGO_VERSION
 from django.core.management.commands import makemessages
 from django.template.base import BLOCK_TAG_START, BLOCK_TAG_END
+from django.utils.translation import template as trans_real
 
-if DJANGO_VERSION[:2] < (1, 11):
-    from django.utils.translation import trans_real
-else:
-    from django.utils.translation import template as trans_real
 
 strip_whitespace_right = re.compile(r"(%s-?\s*(trans|pluralize).*?-%s)\s+" % (BLOCK_TAG_START, BLOCK_TAG_END), re.U)
 strip_whitespace_left = re.compile(r"\s+(%s-\s*(endtrans|pluralize).*?-?%s)" % (BLOCK_TAG_START, BLOCK_TAG_END), re.U)
@@ -58,7 +54,7 @@ class Command(makemessages.Command):
         trans_real.endblock_re = re.compile(
             trans_real.endblock_re.pattern + '|' + r"""^-?\s*endtrans\s*-?$""")
         trans_real.block_re = re.compile(
-            trans_real.block_re.pattern + '|' + r"""^-?\s*trans(?:\s+(?!'|")(?=.*?=.*?)|\s*-?$)""")
+            trans_real.block_re.pattern + '|' + r"""^-?\s*trans(?:\s+(?!'|")(?=.*?)|\s*-?$)""")
         trans_real.plural_re = re.compile(
             trans_real.plural_re.pattern + '|' + r"""^-?\s*pluralize(?:\s+.+|-?$)""")
         trans_real.constant_re = re.compile(r""".*?_\(((?:".*?(?<!\\)")|(?:'.*?(?<!\\)')).*?\)""")
