@@ -1,14 +1,10 @@
 import datetime
 
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+from unittest import mock
 
-import django
+from django.conf import global_settings
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.urls import NoReverseMatch
 from django.urls import reverse
 from django.middleware import csrf
 from django.shortcuts import render
@@ -18,6 +14,8 @@ from django.template.loader import get_template
 from django.test import TestCase
 from django.test import override_settings
 from django.test.client import RequestFactory
+from django.utils import timezone
+from django_jinja.backend import Jinja2
 from django_jinja.base import get_match_extension
 from django_jinja.base import match_template
 from django_jinja.views.generic.base import Jinja2TemplateResponseMixin
@@ -40,18 +38,16 @@ class RenderTemplatesTests(TestCase):
             ("{{ num|floatformat }}", {'num': 34.23234}, '34.2'),
             ("{{ num|floatformat(3) }}", {'num': 34.23234}, '34.232'),
             ("{{ 'hola'|capfirst }}", {}, "Hola"),
-            # The list of Django 1.11 truncator / Django 2.2 truncator result.
-            ("{{ 'hola mundo'|truncatechars(5) }}", {}, ["ho...", "hola…"]),
-            ("{{ 'hola mundo'|truncatechars_html(5) }}", {}, ["ho...", "hola…"]),
-            ("{{ 'hola mundo'|truncatewords(1) }}", {}, ["hola ...", "hola …"]),
-            ("{{ 'hola mundo'|truncatewords_html(1) }}", {}, ["hola ...", "hola …"]),
+            ("{{ 'hola mundo'|truncatechars(5) }}", {}, "hola…"),
+            ("{{ 'hola mundo'|truncatechars_html(5) }}", {}, "hola…"),
+            ("{{ 'hola mundo'|truncatewords(1) }}", {}, "hola …"),
+            ("{{ 'hola mundo'|truncatewords_html(1) }}", {}, "hola …"),
             ("{{ 'hola mundo'|wordwrap(1) }}", {}, "hola\nmundo"),
             ("{{ 'hola mundo'|title }}", {}, "Hola Mundo"),
             ("{{ 'hola mundo'|slugify }}", {}, "hola-mundo"),
             ("{{ 'hello'|ljust(10) }}", {}, "hello     "),
             ("{{ 'hello'|rjust(10) }}", {}, "     hello"),
-            # Django 2.2 does not close br tag.
-            ("{{ 'hello\nworld'|linebreaksbr }}", {}, ["hello<br />world", "hello<br>world"]),
+            ("{{ 'hello\nworld'|linebreaksbr }}", {}, "hello<br>world"),
             ("{{ '<div>hello</div>'|striptags }}", {}, "hello"),
             ("{{ list|join(',') }}", {'list':['a','b']}, 'a,b'),
             ("{{ 3|add(2) }}", {}, "5"),
@@ -65,10 +61,7 @@ class RenderTemplatesTests(TestCase):
             print("- Testing: ", template_str, "with:", kwargs)
             template = self.env.from_string(template_str)
             _result = template.render(kwargs)
-            if isinstance(result, str):
-                self.assertEqual(_result, result)
-            else:
-                self.assertTrue(_result in result)
+            self.assertEqual(_result, result)
 
     def test_string_interpolation(self):
         template = self.env.from_string("{{ 'Hello %s!' % name }}")
@@ -125,7 +118,6 @@ class RenderTemplatesTests(TestCase):
         result = template.render({"form": form})
 
         self.assertIn('maxlength="2"', result)
-        # Django 2.2 does not use "/>" for input html.
         self.assertIn("<input ", result)
 
     def test_autoscape_with_form_field(self):
@@ -134,7 +126,6 @@ class RenderTemplatesTests(TestCase):
         result = template.render({"form": form})
 
         self.assertIn('maxlength="2"', result)
-        # Django 2.2 does not use "/>" for input html.
         self.assertIn("<input ", result)
 
     def test_autoscape_with_form_errors(self):
@@ -169,10 +160,7 @@ class RenderTemplatesTests(TestCase):
     def test_autoescape_03(self):
         template = self.env.from_string("{{ foo|linebreaksbr }}")
         result = template.render({"foo": "<script>alert(1)</script>\nfoo"})
-        self.assertTrue(result in [
-            "&lt;script&gt;alert(1)&lt;/script&gt;<br />foo",  # Django 1.11
-            "&lt;script&gt;alert(1)&lt;/script&gt;<br>foo",    # Django 2.2
-        ])
+        self.assertEqual(result, "&lt;script&gt;alert(1)&lt;/script&gt;<br>foo")
 
     def test_debug_var_when_render_shortcut_is_used(self):
         prev_debug_value = settings.DEBUG
@@ -208,14 +196,8 @@ class RenderTemplatesTests(TestCase):
             request = self.factory.get('/customer/details')
             token = csrf.get_token(request)
 
-            if django.VERSION[:2] >= (1, 8):
-                template = self.env.from_string(template_content)
-                result = template.render({}, request)
-
-            else:
-                context = RequestContext(request)
-                template = self.env.from_string(template_content)
-                result = template.render(context)
+            template = self.env.from_string(template_content)
+            result = template.render({}, request)
 
             expected = ("<input type='hidden' name='csrfmiddlewaretoken'"
                         " value='{}' />").format(token)
@@ -259,13 +241,10 @@ class RenderTemplatesTests(TestCase):
         self.assertEqual(response.content, b"500")
 
     def test_get_default(self):
-        from django_jinja.backend import Jinja2
         Jinja2.get_default.cache_clear()
         self.assertEqual(Jinja2.get_default(), self.env)
 
     def test_get_default_multiple(self):
-        from django_jinja.backend import Jinja2
-
         setting = {
             "append": [
                 {
@@ -284,9 +263,6 @@ class RenderTemplatesTests(TestCase):
                 Jinja2.get_default()
 
     def test_get_default_none(self):
-        from django.conf import global_settings
-        from django_jinja.backend import Jinja2
-
         with self.settings(TEMPLATES=global_settings.TEMPLATES):
             with self.assertRaisesRegexp(ImproperlyConfigured, r'No Jinja2 backend is configured'):
                 Jinja2.get_default()
@@ -376,11 +352,7 @@ class BaseTests(TestCase):
             match_template('admin/foo.html', regex=r"^(?!admin/.*)", extension=None))
 
     def test_get_match_extension(self):
-        if django.VERSION[:2] < (1, 8):
-            self.assertEquals(getattr(settings, 'DEFAULT_JINJA2_TEMPLATE_EXTENSION', '.jinja'), get_match_extension())
-        else:
-            from django_jinja.backend import Jinja2
-            self.assertEquals(Jinja2.get_default().match_extension, get_match_extension())
+        self.assertEquals(Jinja2.get_default().match_extension, get_match_extension())
 
     def test_get_match_extension_using(self):
         setting = {
@@ -459,8 +431,6 @@ class TemplateResponseTests(TestCase):
 
 class GenericViewTests(TestCase):
     def setUp(self):
-        from django.utils import timezone
-
         self.obj1 = TestModel.objects.create(date=timezone.now())
         self.obj2 = TestModel.objects.create(date=timezone.now())
 
